# filter out bogus auto-requires
%global __requires_exclude ^devel\\(libMoleQueue.*)$

Name:		avogadrolibs
Version:	1.93.0
Release:	%mkrel 4
Summary:	An advanced molecular editor
License:	BSD
Group:		Sciences/Chemistry
Url:		http://www.openchemistry.org/projects/avogadro2/
Source0:	https://github.com/OpenChemistry/avogadrolibs/archive/%{version}/%{name}-%{version}.tar.gz
# External source code for avogadrolibs >= 1.91.0
# See https://github.com/OpenChemistry/avogadrolibs/issues/362
%global commit	84443126ba5529fc134068047c206f0b3b7b823b
Source1:	https://github.com/OpenChemistry/avogenerators/archive/%{commit}/avogenerators-%{commit}.tar.gz
Patch0:		avogadrolibs-1.90.0-fix-cmake.patch
BuildRequires:	cmake
BuildRequires:	boost-devel
BuildRequires:	spglib-devel
BuildRequires:	cmake(libmsym)
BuildRequires:	cmake(MoleQueue)
BuildRequires:	pkgconfig(eigen3)
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(libarchive)
BuildRequires:	pkgconfig(Qt5Concurrent)
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Help)
BuildRequires:	pkgconfig(Qt5Network)
BuildRequires:	pkgconfig(Qt5OpenGL)
BuildRequires:	pkgconfig(Qt5Widgets)

%description
Avogadro is an advanced molecular editor designed for cross-platform use in
computational chemistry, molecular modeling, bioinformatics, materials science,
and related areas. It offers flexible rendering and a powerful plugin
architecture. The code in this repository is a rewrite of Avogadro with source
code split across a libraries repository and an application repository. Core
features and goals of the Avogadro project:

  * Open source distributed under the liberal 3-clause BSD license
  * Cross platform with nightly builds on Linux, Mac OS X and Windows
  * Intuitive interface designed to be useful to whole community
  * Fast and efficient embracing the latest technologies
  * Extensible, making extensive use of a plugin architecture
  * Flexible supporting a range of chemical data formats and packages

%files
%doc avogadrogenerators/README-avogenerators.md
%doc thirdparty/libgwavi/README-libgwavi.md
%doc %{_docdir}/AvogadroLibs/
%license LICENSE
%{_libdir}/avogadro2/

#----------------------------------------------------

%define core_major		1
%define libcorename		%mklibname avogadrocore %{core_major}

%package -n	%{libcorename}
Summary:	Avogadro Core library
Group:		System/Libraries
Requires:	%{name} >= %{version}-%{release}

%description -n	%{libcorename}
Avogadro Core library.

%files -n %{libcorename}
%{_libdir}/libAvogadroCore.so.%{core_major}{,.*}

#----------------------------------------------------

%define io_major		1
%define libioname		%mklibname avogadroio %{io_major}

%package -n	%{libioname}
Summary:	Avogadro IO library
Group:		System/Libraries

%description -n	%{libioname}
Avogadro IO library.

%files -n %{libioname}
%{_libdir}/libAvogadroIO.so.%{io_major}{,.*}

#----------------------------------------------------

%define molequeue_major		1
%define libmolequeuename	%mklibname avogadromolequeue %{molequeue_major}

%package -n	%{libmolequeuename}
Summary:	Avogadro MoleQueue library
Group:		System/Libraries

%description -n	%{libmolequeuename}
Avogadro MoleQueue library.

%files -n %{libmolequeuename}
%{_libdir}/libAvogadroMoleQueue.so.%{molequeue_major}{,.*}

#----------------------------------------------------

%define qtgui_major		1
%define libqtguiname		%mklibname avogadroqtgui %{qtgui_major}

%package -n	%{libqtguiname}
Summary:	Avogadro Qt Gui library
Group:		System/Libraries

%description -n	%{libqtguiname}
Avogadro Qt Gui library.

%files -n %{libqtguiname}
%{_libdir}/libAvogadroQtGui.so.%{qtgui_major}{,.*}

#----------------------------------------------------

%define qtopengl_major		1
%define libqtopenglname		%mklibname avogadroqtopengl %{qtopengl_major}

%package -n	%{libqtopenglname}
Summary:	Avogadro Qt OpenGL library
Group:		System/Libraries

%description -n	%{libqtopenglname}
Avogadro Qt OpenGL library.

%files -n %{libqtopenglname}
%{_libdir}/libAvogadroQtOpenGL.so.%{qtopengl_major}{,.*}

#----------------------------------------------------

%define qtplugins_major		1
%define libqtpluginsname	%mklibname avogadroqtplugins %{qtplugins_major}

%package -n	%{libqtpluginsname}
Summary:	Avogadro Qt Plugins library
Group:		System/Libraries

%description -n	%{libqtpluginsname}
Avogadro Qt Plugins library.

%files -n %{libqtpluginsname}
%{_libdir}/libAvogadroQtPlugins.so.%{qtplugins_major}{,.*}

#----------------------------------------------------

%define quantumio_major		1
%define libquantumioname	%mklibname avogadroquantumio %{quantumio_major}

%package -n	%{libquantumioname}
Summary:	Avogadro Quantum IO library
Group:		System/Libraries

%description -n	%{libquantumioname}
Avogadro Quantum IO library.

%files -n %{libquantumioname}
%{_libdir}/libAvogadroQuantumIO.so.%{quantumio_major}{,.*}

#----------------------------------------------------

%define rendering_major		1
%define librenderingname	%mklibname avogadrorendering %{rendering_major}

%package -n	%{librenderingname}
Summary:	Avogadro Rendering library
Group:		System/Libraries

%description -n	%{librenderingname}
Avogadro Rendering library.

%files -n %{librenderingname}
%{_libdir}/libAvogadroRendering.so.%{rendering_major}{,.*}

#----------------------------------------------------

%define devname		%mklibname %{name} -d

%package -n	%{devname}
Summary:	Development files for %{name}
Group:		Development/Other
Requires:	%{name} >= %{version}-%{release}
Requires:	%{libcorename} >= %{version}-%{release}
Requires:	%{libioname} >= %{version}-%{release}
Requires:	%{libmolequeuename} >= %{version}-%{release}
Requires:	%{libqtguiname} >= %{version}-%{release}
Requires:	%{libqtopenglname} >= %{version}-%{release}
Requires:	%{libqtpluginsname} >= %{version}-%{release}
Requires:	%{libquantumioname} >= %{version}-%{release}
Requires:	%{librenderingname} >= %{version}-%{release}
Requires:	cmake(MoleQueue)
Provides:	avogadro2-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Obsoletes:	%{name}-devel < 1.90.0-7

%description -n	%{devname}
The %{devname} package contains header files for developing applications
that use %{name}.

%files -n %{devname}
%{_includedir}/avogadro/
%{_libdir}/cmake/%{name}/
%{_libdir}/*.so
%{_libdir}/liblibgwavi.a

#----------------------------------------------------

%prep
%setup -q -a 1
%autopatch -p1

# Make avogadro generators source code available for CMake
mv avogenerators-%{commit} avogadrogenerators
mv avogadrogenerators/README.md avogadrogenerators/README-avogenerators.md
sed -e 's|../avogadrogenerators|avogadrogenerators|g' -i avogadro/qtplugins/quantuminput/CMakeLists.txt

mv thirdparty/libgwavi/README.md thirdparty/libgwavi/README-libgwavi.md

%build
%cmake_qt5 \
	-DCMAKE_INSTALL_LIBDIR=%{_lib} \
	-DUSE_MMTF=OFF \
	-DENABLE_TRANSLATIONS=ON

%cmake_build

%install
%cmake_install


%changelog
* Wed Dec 16 2020 umeabot <umeabot> 1.93.0-4.mga8
+ Revision: 1658147
- Rebuild for new Qt5

* Wed Dec 02 2020 luigiwalser <luigiwalser> 1.93.0-3.mga8
+ Revision: 1651337
- rebuild for glew

* Thu Feb 20 2020 umeabot <umeabot> 1.93.0-2.mga8
+ Revision: 1547096
- Mageia 8 Mass Rebuild

* Thu Feb 06 2020 daviddavid <daviddavid> 1.93.0-1.mga8
+ Revision: 1487520
- new version: 1.93.0

* Wed Jan 01 2020 daviddavid <daviddavid> 1.92.1-1.mga8
+ Revision: 1475369
- new version: 1.92.1
+ wally <wally>
- build with new cmake macros

* Sat Mar 30 2019 umeabot <umeabot> 1.91.0-3.mga7
+ Revision: 1381298
- Qt5 Rebuild

* Fri Sep 21 2018 umeabot <umeabot> 1.91.0-2.mga7
+ Revision: 1295206
- Mageia 7 Mass Rebuild

* Sat Aug 25 2018 daviddavid <daviddavid> 1.91.0-1.mga7
+ Revision: 1254155
- new version: 1.91.0
- remove merged upstream patch
- use system libmsym
- now all libs are in a separate sub-pkgs
- fix devel pkg name
- need now external avogenerators source code

* Sat Jun 02 2018 daviddavid <daviddavid> 1.90.0-6.mga7
+ Revision: 1233617
- add upstream patch to fix build with new Qt5 >= 5.11.0

* Sun Dec 03 2017 daviddavid <daviddavid> 1.90.0-5.mga7
+ Revision: 1180776
- rebuild for new glew 2.1.0

* Wed Oct 11 2017 daviddavid <daviddavid> 1.90.0-4.mga7
+ Revision: 1171058
- patch1: fix build with gcc7

* Sat Aug 05 2017 daviddavid <daviddavid> 1.90.0-3.mga7
+ Revision: 1136092
- rebuild for new glew 2.0.0

* Tue Jan 31 2017 barjac <barjac> 1.90.0-2.mga6
+ Revision: 1084310
- Rebuild for eigen3

* Tue Dec 13 2016 daviddavid <daviddavid> 1.90.0-1.mga6
+ Revision: 1074495
- initial package avogadrolibs

